@@ -31,9 +31,9 @@ Basic assumptions
 3) As a consequence, particles that are self-conjugate should not be used
    in 'CDecay' statements, obviously.
 
- 4) Decays defined via a 'CopyDecay' statement are simply (deep) copied
-    and no copy of the corresponding antiparticle is performed unless explicitly requested
-    with another 'CopyDecay' statement.
+4) Decays defined via a 'CopyDecay' statement are simply (deep) copied
+   and no copy of the corresponding antiparticle is performed unless explicitly requested
+   with another 'CopyDecay' statement.
 """
 
 
@@ -142,7 +142,7 @@ class DecFileParser:
         cls: Type[Self_DecFileParser], filecontent: str
     ) -> Self_DecFileParser:
         """
-        Parse a .dec decay file provided as a multi-line string.
+        Constructor from a .dec decay file provided as a multi-line string.
 
         Parameters
         ----------
@@ -158,7 +158,7 @@ class DecFileParser:
 
         return _cls
 
-    def parse(self, include_ccdecays: Optional[bool] = True) -> None:
+    def parse(self, include_ccdecays: bool = True) -> None:
         """
         Parse the given .dec decay file(s) according to the default Lark parser
         and specified options.
@@ -173,7 +173,7 @@ class DecFileParser:
             Choose whether or not to consider charge-conjugate decays,
             which are specified via "CDecay <MOTHER>".
             Make sure you understand the consequences of ignoring
-            charge conjugate decays - you won't have a complete picture!
+            charge conjugate decays - you won't have a complete picture otherwise!
         """
         # Has a file been parsed already?
         if self._parsed_decays is not None:
@@ -279,9 +279,6 @@ class DecFileParser:
             with data.basepath.joinpath(filename).open() as f1:
                 self._grammar = f1.read()
         else:
-            # Conversion to handle pathlib on Python < 3.6:
-            filename = str(filename)
-
             with open(filename) as f2:
                 self._grammar = f2.read()
 
@@ -303,6 +300,7 @@ class DecFileParser:
         "CopyDecay <NAME> <DECAY_TO_COPY>",
         as {'NAME1': DECAY_TO_COPY1, 'NAME2': DECAY_TO_COPY2, ...}.
         """
+        self._check_parsing()
         return get_decays2copy_statements(self._parsed_dec_file)
 
     def dict_definitions(self) -> Dict[str, float]:
@@ -311,6 +309,7 @@ class DecFileParser:
         of the form "Define <NAME> <VALUE>",
         as {'NAME1': VALUE1, 'NAME2': VALUE2, ...}.
         """
+        self._check_parsing()
         return get_definitions(self._parsed_dec_file)
 
     def dict_aliases(self) -> Dict[str, str]:
@@ -319,6 +318,7 @@ class DecFileParser:
         of the form "Alias <NAME> <ALIAS>",
         as {'NAME1': ALIAS1, 'NAME2': ALIAS2, ...}.
         """
+        self._check_parsing()
         return get_aliases(self._parsed_dec_file)
 
     def dict_charge_conjugates(self) -> Dict[str, str]:
@@ -328,6 +328,7 @@ class DecFileParser:
         "ChargeConj <PARTICLE> <CC_PARTICLE>", as
         {'PARTICLE1': CC_PARTICLE1, 'PARTICLE2': CC_PARTICLE2, ...}.
         """
+        self._check_parsing()
         return get_charge_conjugate_defs(self._parsed_dec_file)
 
     def dict_pythia_definitions(self) -> Dict[str, Union[str, float]]:
@@ -339,6 +340,7 @@ class DecFileParser:
         "PythiaBothParam <NAME>=<NUMBER>",
         as {'NAME1': 'LABEL1', 'NAME2': VALUE2, ...}.
         """
+        self._check_parsing()
         return get_pythia_definitions(self._parsed_dec_file)
 
     def dict_jetset_definitions(self) -> Dict[str, Dict[int, Union[int, float, str]]]:
@@ -350,6 +352,7 @@ class DecFileParser:
             'PARAM2': {...},
             ...}.
         """
+        self._check_parsing()
         return get_jetset_definitions(self._parsed_dec_file)
 
     def list_lineshape_definitions(self) -> List[Tuple[List[str], int]]:
@@ -362,6 +365,7 @@ class DecFileParser:
         (['MOTHER2', 'DAUGHTER2-1', 'DAUGHTER2-2'], VALUE2),
         ...]
         """
+        self._check_parsing()
         return get_lineshape_definitions(self._parsed_dec_file)
 
     def global_photos_flag(self) -> int:
@@ -377,6 +381,7 @@ class DecFileParser:
         out: PhotosEnum, default=PhotosEnum.no
             PhotosEnum.yes / PhotosEnum.no if PHOTOS enabled / disabled
         """
+        self._check_parsing()
         return get_global_photos_flag(self._parsed_dec_file)
 
     def list_charge_conjugate_decays(self) -> List[str]:
@@ -385,6 +390,7 @@ class DecFileParser:
         in the input parsed file, of the form "CDecay <MOTHER>", as
         ['MOTHER1', 'MOTHER2', ...].
         """
+        self._check_parsing()
         return get_charge_conjugate_decays(self._parsed_dec_file)
 
     def _find_parsed_decays(self) -> None:
@@ -403,8 +409,7 @@ class DecFileParser:
         2) Charge conjugates need to be dealt with differently,
         see 'self._add_charge_conjugate_decays()'.
         """
-        if self._parsed_dec_file is not None:
-            self._parsed_decays = get_decays(self._parsed_dec_file)
+        self._parsed_decays = get_decays(self._parsed_dec_file)
 
         # Check for duplicates - should be considered a bug in the .dec file!
         self._check_parsed_decays()
@@ -635,9 +640,7 @@ All but the first occurrence will be discarded/removed ...""".format(
 
         raise DecayNotFound("Decays of particle '%s' not found in .dec file!" % mother)
 
-    def list_decay_modes(
-        self, mother: str, pdg_name: Optional[bool] = False
-    ) -> List[List[str]]:
+    def list_decay_modes(self, mother: str, pdg_name: bool = False) -> List[List[str]]:
         """
         Return a list of decay modes for the given mother particle.
 
@@ -665,7 +668,7 @@ All but the first occurrence will be discarded/removed ...""".format(
         ]
 
     def _decay_mode_details(
-        self, decay_mode: Tree, display_photos_keyword: Optional[bool] = True
+        self, decay_mode: Tree, display_photos_keyword: bool = True
     ) -> Tuple[float, List[str], str, Union[str, List[Union[str, Any]]]]:
         """
         Parse a decay mode (Tree instance)
@@ -692,14 +695,17 @@ All but the first occurrence will be discarded/removed ...""".format(
     def print_decay_modes(
         self,
         mother: str,
-        pdg_name: Optional[bool] = False,
-        print_model: Optional[bool] = True,
-        display_photos_keyword: Optional[bool] = True,
-        ascending: Optional[bool] = False,
-        normalize: Optional[bool] = True,
+        pdg_name: bool = False,
+        print_model: bool = True,
+        display_photos_keyword: bool = True,
+        ascending: bool = False,
+        normalize: bool = False,
+        scale: Optional[float] = None,
     ) -> None:
         """
-        Pretty print of the decay modes of a given particle.
+        Pretty print of the decay modes of a given particle,
+        optionally with decay model information and/or normalisation or scaling
+        of the branching fractions.
 
         Parameters
         ----------
@@ -716,10 +722,63 @@ All but the first occurrence will be discarded/removed ...""".format(
         ascending: bool, optional, default=False
             Print the list of decay modes ordered in ascending/descending order
             of branching fraction.
-        normalize: bool, optional, default=True
-            Print the branching fractions normalized to unity
-            (this does not affect the values parsed and actually stored in memory).
+        normalize: bool, optional, default=False
+            Print the branching fractions normalized to unity.
+            The printing does not affect the values parsed and actually stored in memory.
+        scale: float | None, optional, default=None
+            If not None, the branching fractions (BFs) are normalized to the given value,
+            which is taken to be the BF of the highest-BF mode of the list.
+            Must be a number in the range ]0, 1].
+
+        Examples
+        --------
+        >>> s = '''Decay MyD_0*+
+        ...  0.533   MyD0   pi+        PHSP;
+        ...  0.08    MyD*0  pi+  pi0   PHSP;
+        ...  0.0271  MyD*+  pi0  pi0   PHSP;
+        ...  0.0542  MyD*+  pi+  pi-   PHSP;
+        ... Enddecay
+        ... '''
+        >>> p = DecFileParser.from_string(s)
+        >>> p.parse()
+        >>>
+        >>> # Simply print what has been parsed
+        >>> p.print_decay_modes("MyD_0*+")
+          0.533             MyD0  pi+         PHSP;
+          0.08              MyD*0 pi+ pi0     PHSP;
+          0.0542            MyD*+ pi+ pi-     PHSP;
+          0.0271            MyD*+ pi0 pi0     PHSP;
+        >>>
+        >>> # Print normalizing the sum of all mode BFs to unity
+        >>> p.print_decay_modes("MyD_0*+", normalize=True)
+          0.7676796774      MyD0  pi+         PHSP;
+          0.1152239666      MyD*0 pi+ pi0     PHSP;
+          0.07806423736     MyD*+ pi+ pi-     PHSP;
+          0.03903211868     MyD*+ pi0 pi0     PHSP;
+        >>>
+        >>> # Print scaling all BFs relative to the BF of the highest-BF mode in the list,
+        >>> # the latter being set to the value of "scale".
+        >>> # In this example the decay file as printed would effectively signal, for inspection,
+        >>> # that about 35% of the total decay width is not accounted for in the list of modes,
+        >>> # since the sum of probabilities, interpreted as BFs, sum to about 65%.
+        >>> p.print_decay_modes("MyD_0*+", scale=0.5)
+          0.5               MyD0  pi+         PHSP;
+          0.07504690432     MyD*0 pi+ pi0     PHSP;
+          0.05084427767     MyD*+ pi+ pi-     PHSP;
+          0.02542213884     MyD*+ pi0 pi0     PHSP;
         """
+
+        if scale is not None:
+            # One cannot normalize and scale at the same time, clearly
+            if normalize:
+                raise RuntimeError(
+                    "Be consistent - use either 'normalize' and 'scale'!"
+                )
+            elif not (0.0 < scale <= 1.0):
+                raise RuntimeError(
+                    "A branching fraction must be in the range ]0, 1]! You set scale = {scale}."
+                )
+
         if pdg_name:
             mother = PDG2EvtGenNameMap[mother]
 
@@ -742,18 +801,25 @@ All but the first occurrence will be discarded/removed ...""".format(
 
         ls = [(bf, ls_attrs_aligned[idx]) for idx, bf in enumerate(ls_dict)]
         ls.sort(key=operator.itemgetter(0), reverse=(not ascending))
-        norm = sum(bf for bf, _ in ls) if normalize else 1
+
+        norm = 1.0
+        if normalize:
+            norm = sum(bf for bf, _ in ls)
+        elif scale is not None:
+            # Get the largest branching fraction
+            i = -1 if ascending else 0
+            norm = ls[i][0] / scale
 
         for bf, info in ls:
             if print_model:
-                line = "  {:.4f}   {}     {}  {}".format(bf / norm, *info)
+                line = "  {:<15.10g}   {}     {}  {}".format(bf / norm, *info)
             else:
-                line = f"  {bf / norm:.4f}   {info[0]}"
+                line = f"  {bf / norm:<15.10g}   {info[0]}"
             print(line.rstrip() + ";")
 
     @staticmethod
     def _align_items(
-        to_align: str, align_mode: Optional[str] = "left", sep: Optional[str] = " "
+        to_align: str, align_mode: str = "left", sep: str = " "
     ) -> List[str]:
         """
         Left or right align all strings in a list to the same length.
@@ -1022,7 +1088,7 @@ def get_decay_mother_name(decay_tree: Tree) -> Union[str, Any]:
     decay_tree: Lark Tree instance
         Input Tree satisfying Tree.data=='decay'.
     """
-    if not isinstance(decay_tree, Tree) or decay_tree.data != "decay":
+    if decay_tree.data != "decay":
         raise RuntimeError("Input not an instance of a 'decay' Tree!")
 
     # For a 'decay' Tree, tree.children[0] is the mother particle Tree
@@ -1040,7 +1106,7 @@ def get_branching_fraction(decay_mode: Tree) -> float:
     decay_mode: Lark Tree instance
         Input Tree satisfying Tree.data=='decayline'.
     """
-    if not isinstance(decay_mode, Tree) or decay_mode.data != "decayline":
+    if decay_mode.data != "decayline":
         raise RuntimeError("Check your input, not an instance of a 'decayline' Tree!")
 
     # For a 'decayline' Tree, Tree.children[0] is the branching fraction Tree
@@ -1073,7 +1139,7 @@ def get_final_state_particles(decay_mode: Tree) -> List[Tree]:
         [Tree(particle, [Token(LABEL, 'K+')]), Tree(particle, [Token(LABEL, 'K-')])]
     will be returned.
     """
-    if not isinstance(decay_mode, Tree) or decay_mode.data != "decayline":
+    if decay_mode.data != "decayline":
         raise RuntimeError("Input not an instance of a 'decayline' Tree!")
 
     # list of Trees of final-state particles
@@ -1098,7 +1164,7 @@ def get_final_state_particle_names(decay_mode: Tree) -> List[str]:
         Enddecay
     the list ['K+', 'K-'] will be returned.
     """
-    if not isinstance(decay_mode, Tree) or decay_mode.data != "decayline":
+    if decay_mode.data != "decayline":
         raise RuntimeError("Input not an instance of a 'decayline' Tree!")
 
     fsps = get_final_state_particles(decay_mode)
@@ -1123,7 +1189,7 @@ def get_model_name(decay_mode: Tree) -> str:
         Enddecay
     the string 'SSD_CP' will be returned.
     """
-    if not isinstance(decay_mode, Tree) or decay_mode.data != "decayline":
+    if decay_mode.data != "decayline":
         raise RuntimeError("Input not an instance of a 'decayline' Tree!")
 
     lm = list(decay_mode.find_data("model"))
@@ -1158,7 +1224,7 @@ def get_model_parameters(decay_mode: Tree) -> Union[str, List[Union[str, Any]]]:
         ['DtoKpipipi_v1']
     will be returned.
     """
-    if not isinstance(decay_mode, Tree) or decay_mode.data != "decayline":
+    if decay_mode.data != "decayline":
         raise RuntimeError("Input not an instance of a 'decayline' Tree!")
 
     lmo = list(decay_mode.find_data("model_options"))
@@ -1172,7 +1238,7 @@ def get_model_parameters(decay_mode: Tree) -> Union[str, List[Union[str, Any]]]:
     return [_value(tree) for tree in lmo[0].children] if len(lmo) == 1 else ""
 
 
-def get_decays(parsed_file: Optional[str]) -> List[Tree]:
+def get_decays(parsed_file: Tree) -> List[Tree]:
     """
     Return a list of all decay definitions in the input parsed file,
     of the form "Decay <MOTHER>",
@@ -1185,9 +1251,6 @@ def get_decays(parsed_file: Optional[str]) -> List[Tree]:
     parsed_file: Lark Tree instance
         Input parsed file.
     """
-    if not isinstance(parsed_file, Tree):
-        raise RuntimeError("Input not an instance of a Tree!")
-
     try:
         return list(parsed_file.find_data("decay"))
     except Exception as err:
@@ -1196,7 +1259,7 @@ def get_decays(parsed_file: Optional[str]) -> List[Tree]:
         ) from err
 
 
-def get_charge_conjugate_decays(parsed_file: Optional[str]) -> List[str]:
+def get_charge_conjugate_decays(parsed_file: Tree) -> List[str]:
     """
     Return a (sorted) list of all charge conjugate decay definitions
     in the input parsed file, of the form "CDecay <MOTHER>", as
@@ -1207,8 +1270,6 @@ def get_charge_conjugate_decays(parsed_file: Optional[str]) -> List[str]:
     parsed_file: Lark Tree instance
         Input parsed file.
     """
-    if not isinstance(parsed_file, Tree):
-        raise RuntimeError("Input not an instance of a Tree!")
 
     try:
         return sorted(
@@ -1221,7 +1282,7 @@ def get_charge_conjugate_decays(parsed_file: Optional[str]) -> List[str]:
         ) from err
 
 
-def get_decays2copy_statements(parsed_file: Optional[str]) -> Dict[str, str]:
+def get_decays2copy_statements(parsed_file: Tree) -> Dict[str, str]:
     """
     Return a dictionary of all statements in the input parsed file
     defining a decay to be copied, of the form
@@ -1233,9 +1294,6 @@ def get_decays2copy_statements(parsed_file: Optional[str]) -> Dict[str, str]:
     parsed_file: Lark Tree instance
         Input parsed file.
     """
-    if not isinstance(parsed_file, Tree):
-        raise RuntimeError("Input not an instance of a Tree!")
-
     try:
         return {
             tree.children[0].children[0].value: tree.children[1].children[0].value
@@ -1247,7 +1305,7 @@ def get_decays2copy_statements(parsed_file: Optional[str]) -> Dict[str, str]:
         ) from err
 
 
-def get_definitions(parsed_file: Optional[str]) -> Dict[str, float]:
+def get_definitions(parsed_file: Tree) -> Dict[str, float]:
     """
     Return a dictionary of all definitions in the input parsed file, of the form
     "Define <NAME> <VALUE>", as {'NAME1': VALUE1, 'NAME2': VALUE2, ...}.
@@ -1257,9 +1315,6 @@ def get_definitions(parsed_file: Optional[str]) -> Dict[str, float]:
     parsed_file: Lark Tree instance
         Input parsed file.
     """
-    if not isinstance(parsed_file, Tree):
-        raise RuntimeError("Input not an instance of a Tree!")
-
     try:
         return {
             tree.children[0]
@@ -1273,7 +1328,7 @@ def get_definitions(parsed_file: Optional[str]) -> Dict[str, float]:
         ) from err
 
 
-def get_aliases(parsed_file: Optional[str]) -> Dict[str, str]:
+def get_aliases(parsed_file: Tree) -> Dict[str, str]:
     """
     Return a dictionary of all aliases in the input parsed file, of the form
     "Alias <NAME> <ALIAS>", as {'NAME1': ALIAS1, 'NAME2': ALIAS2, ...}.
@@ -1283,9 +1338,6 @@ def get_aliases(parsed_file: Optional[str]) -> Dict[str, str]:
     parsed_file: Lark Tree instance
         Input parsed file.
     """
-    if not isinstance(parsed_file, Tree):
-        raise RuntimeError("Input not an instance of a Tree!")
-
     try:
         return {
             tree.children[0].children[0].value: tree.children[1].children[0].value
@@ -1297,7 +1349,7 @@ def get_aliases(parsed_file: Optional[str]) -> Dict[str, str]:
         ) from err
 
 
-def get_charge_conjugate_defs(parsed_file: Optional[str]) -> Dict[str, str]:
+def get_charge_conjugate_defs(parsed_file: Tree) -> Dict[str, str]:
     """
     Return a dictionary of all charge conjugate definitions
     in the input parsed file, of the form "ChargeConj <PARTICLE> <CC_PARTICLE>",
@@ -1308,9 +1360,6 @@ def get_charge_conjugate_defs(parsed_file: Optional[str]) -> Dict[str, str]:
     parsed_file: Lark Tree instance
         Input parsed file.
     """
-    if not isinstance(parsed_file, Tree):
-        raise RuntimeError("Input not an instance of a Tree!")
-
     try:
         return {
             tree.children[0].children[0].value: tree.children[1].children[0].value
@@ -1322,7 +1371,7 @@ def get_charge_conjugate_defs(parsed_file: Optional[str]) -> Dict[str, str]:
         ) from err
 
 
-def get_pythia_definitions(parsed_file: Optional[str]) -> Dict[str, Union[str, float]]:
+def get_pythia_definitions(parsed_file: Tree) -> Dict[str, Union[str, float]]:
     """
     Return a dictionary of all Pythia definitions in the input parsed file,
     of the form
@@ -1336,8 +1385,6 @@ def get_pythia_definitions(parsed_file: Optional[str]) -> Dict[str, Union[str, f
     parsed_file: Lark Tree instance
         Input parsed file.
     """
-    if not isinstance(parsed_file, Tree):
-        raise RuntimeError("Input not an instance of a Tree!")
 
     def str_or_float(arg: str) -> Union[str, float]:
         try:
@@ -1359,7 +1406,7 @@ def get_pythia_definitions(parsed_file: Optional[str]) -> Dict[str, Union[str, f
 
 
 def get_jetset_definitions(
-    parsed_file: Optional[str],
+    parsed_file: Tree,
 ) -> Dict[str, Dict[int, Union[int, float, str]]]:
     """
     Return a dictionary of all JETSET definitions in the input parsed file,
@@ -1374,9 +1421,6 @@ def get_jetset_definitions(
     parsed_file: Lark Tree instance
         Input parsed file.
     """
-    if not isinstance(parsed_file, Tree):
-        raise RuntimeError("Input not an instance of a Tree!")
-
     get_jetsetpar = re.compile(
         r"""
     ^                                     # Beginning of string
@@ -1421,7 +1465,7 @@ def get_jetset_definitions(
 
 
 def get_lineshape_definitions(
-    parsed_file: Optional[str],
+    parsed_file: Tree,
 ) -> List[Tuple[List[str], int]]:
     """
     Return a list of all SetLineshapePW definitions in the input parsed file,
@@ -1437,9 +1481,6 @@ def get_lineshape_definitions(
     parsed_file: Lark Tree instance
         Input parsed file.
     """
-    if not isinstance(parsed_file, Tree):
-        raise RuntimeError("Input not an instance of a Tree!")
-
     try:
         d = []
         for tree in parsed_file.find_data("setlspw"):
@@ -1453,7 +1494,7 @@ def get_lineshape_definitions(
         ) from err
 
 
-def get_global_photos_flag(parsed_file: Optional[str]) -> int:
+def get_global_photos_flag(parsed_file: Tree) -> int:
     """
     Return a boolean-like PhotosEnum enum specifying whether or not PHOTOS
     has been enabled.
@@ -1471,9 +1512,6 @@ def get_global_photos_flag(parsed_file: Optional[str]) -> int:
     out: PhotosEnum, default=PhotosEnum.no
         PhotosEnum.yes / PhotosEnum.no if PHOTOS enabled / disabled
     """
-    if not isinstance(parsed_file, Tree):
-        raise RuntimeError("Input not an instance of a Tree!")
-
     # Check if the flag is not set more than once, just in case ...
     tree = tuple(parsed_file.find_data("global_photos"))
     if not tree:
