@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/decaylanguage for details.
@@ -94,11 +93,8 @@ class TreeToDec2(Transformer):
 
 @pytest.mark.skip
 def test_dec_full():
-    with data.open_text(data, "DECAY_LHCB.DEC") as f:
-        txt = f.read()
-
-    with data.open_text(data, "decfile.lark") as f:
-        grammar = f.read()
+    txt = data.basepath.joinpath("DECAY_LHCB.DEC").read_text()
+    grammar = data.basepath.joinpath("decfile.lark").read_text()
 
     la = Lark(grammar, parser="lalr", lexer="standard")  # , transformer = TreeToDec())
 
